---
annotations_creators:
- expert-generated
language_creators:
- crowdsourced
languages:
  af_afribooms:
  - af
  akk_pisandub:
  - akk
  akk_riao:
  - akk
  aqz_tudet:
  - aqz
  sq_tsa:
  - sq
  am_att:
  - am
  grc_perseus:
  - grc
  grc_proiel:
  - grc
  apu_ufpa:
  - apu
  ar_nyuad:
  - ar
  ar_padt:
  - ar
  ar_pud:
  - ar
  hy_armtdp:
  - hy
  aii_as:
  - aii
  bm_crb:
  - bm
  eu_bdt:
  - eu
  be_hse:
  - be
  bho_bhtb:
  - bho
  br_keb:
  - br
  bg_btb:
  - bg
  bxr_bdt:
  - bxr
  yue_hk:
  - yue
  ca_ancora:
  - ca
  zh_cfl:
  - zh
  zh_gsd:
  - zh
  zh_gsdsimp:
  - zh
  zh_hk:
  - zh
  zh_pud:
  - zh
  ckt_hse:
  - ckt
  lzh_kyoto:
  - lzh
  cop_scriptorium:
  - cop
  hr_set:
  - hr
  cs_cac:
  - cs
  cs_cltt:
  - cs
  cs_fictree:
  - cs
  cs_pdt:
  - cs
  cs_pud:
  - cs
  da_ddt:
  - da
  nl_alpino:
  - nl
  nl_lassysmall:
  - nl
  en_esl:
  - en
  en_ewt:
  - en
  en_gum:
  - en
  en_gumreddit:
  - en
  en_lines:
  - en
  en_partut:
  - en
  en_pronouns:
  - en
  en_pud:
  - en
  myv_jr:
  - myv
  et_edt:
  - et
  et_ewt:
  - et
  fo_farpahc:
  - fo
  fo_oft:
  - fo
  fi_ftb:
  - fi
  fi_ood:
  - fi
  fi_pud:
  - fi
  fi_tdt:
  - fi
  fr_fqb:
  - fr
  fr_ftb:
  - fr
  fr_gsd:
  - fr
  fr_partut:
  - fr
  fr_pud:
  - fr
  fr_sequoia:
  - fr
  fr_spoken:
  - fr
  gl_ctg:
  - gl
  gl_treegal:
  - gl
  de_gsd:
  - de
  de_hdt:
  - de
  de_lit:
  - de
  de_pud:
  - de
  got_proiel:
  - got
  el_gdt:
  - el
  he_htb:
  - he
  qhe_hiencs:
  - qhe
  hi_hdtb:
  - hi
  hi_pud:
  - hi
  hu_szeged:
  - hu
  is_icepahc:
  - is
  is_pud:
  - is
  id_csui:
  - id
  id_gsd:
  - id
  id_pud:
  - id
  ga_idt:
  - ga
  it_isdt:
  - it
  it_partut:
  - it
  it_postwita:
  - it
  it_pud:
  - it
  it_twittiro:
  - it
  it_vit:
  - it
  ja_bccwj:
  - ja
  ja_gsd:
  - ja
  ja_modern:
  - ja
  ja_pud:
  - ja
  krl_kkpp:
  - krl
  kk_ktb:
  - kk
  kfm_aha:
  - kfm
  koi_uh:
  - koi
  kpv_ikdp:
  - kpv
  kpv_lattice:
  - kpv
  ko_gsd:
  - ko
  ko_kaist:
  - ko
  ko_pud:
  - ko
  kmr_mg:
  - kmr
  la_ittb:
  - la
  la_llct:
  - la
  la_perseus:
  - la
  la_proiel:
  - la
  lv_lvtb:
  - lv
  lt_alksnis:
  - lt
  lt_hse:
  - lt
  olo_kkpp:
  - olo
  mt_mudt:
  - mt
  gv_cadhan:
  - gv
  mr_ufal:
  - mr
  gun_dooley:
  - gun
  gun_thomas:
  - gun
  mdf_jr:
  - mdf
  myu_tudet:
  - myu
  pcm_nsc:
  - pcm
  nyq_aha:
  - nyq
  sme_giella:
  - sme
  no_bokmaal:
  - 'no'
  no_nynorsk:
  - 'no'
  no_nynorsklia:
  - 'no'
  cu_proiel:
  - cu
  fro_srcmf:
  - fro
  orv_rnc:
  - orv
  orv_torot:
  - orv
  otk_tonqq:
  - otk
  fa_perdt:
  - fa
  fa_seraji:
  - fa
  pl_lfg:
  - pl
  pl_pdb:
  - pl
  pl_pud:
  - pl
  pt_bosque:
  - pt
  pt_gsd:
  - pt
  pt_pud:
  - pt
  ro_nonstandard:
  - ro
  ro_rrt:
  - ro
  ro_simonero:
  - ro
  ru_gsd:
  - ru
  ru_pud:
  - ru
  ru_syntagrus:
  - ru
  ru_taiga:
  - ru
  sa_ufal:
  - sa
  sa_vedic:
  - sa
  gd_arcosg:
  - gd
  sr_set:
  - sr
  sms_giellagas:
  - sms
  sk_snk:
  - sk
  sl_ssj:
  - sl
  sl_sst:
  - sl
  soj_aha:
  - soj
  ajp_madar:
  - ajp
  es_ancora:
  - es
  es_gsd:
  - es
  es_pud:
  - es
  swl_sslc:
  - swl
  sv_lines:
  - sv
  sv_pud:
  - sv
  sv_talbanken:
  - sv
  gsw_uzh:
  - gsw
  tl_trg:
  - tl
  tl_ugnayan:
  - tl
  ta_mwtt:
  - ta
  ta_ttb:
  - ta
  te_mtg:
  - te
  th_pud:
  - th
  tpn_tudet:
  - tpn
  qtd_sagt:
  - qtd
  tr_boun:
  - tr
  tr_gb:
  - tr
  tr_imst:
  - tr
  tr_pud:
  - tr
  uk_iu:
  - uk
  hsb_ufal:
  - hsb
  ur_udtb:
  - ur
  ug_udt:
  - ug
  vi_vtb:
  - vi
  wbp_ufal:
  - wbp
  cy_ccg:
  - cy
  wo_wtb:
  - wo
  yo_ytb:
  - yo
licenses:
- unknown
multilinguality:
- multilingual
size_categories:
- 1K<n<10K
source_datasets:
- original
task_categories:
- other
task_ids:
- constituency-parsing
- dependency-parsing
paperswithcode_id: universal-dependencies
pretty_name: Universal Dependencies Treebank
---

# Dataset Card for Universal Dependencies Treebank

## Table of Contents
- [Dataset Description](#dataset-description)
  - [Dataset Summary](#dataset-summary)
  - [Supported Tasks and Leaderboards](#supported-tasks-and-leaderboards)
  - [Languages](#languages)
- [Dataset Structure](#dataset-structure)
  - [Data Instances](#data-instances)
  - [Data Fields](#data-fields)
  - [Data Splits](#data-splits)
- [Dataset Creation](#dataset-creation)
  - [Curation Rationale](#curation-rationale)
  - [Source Data](#source-data)
  - [Annotations](#annotations)
  - [Personal and Sensitive Information](#personal-and-sensitive-information)
- [Considerations for Using the Data](#considerations-for-using-the-data)
  - [Social Impact of Dataset](#social-impact-of-dataset)
  - [Discussion of Biases](#discussion-of-biases)
  - [Other Known Limitations](#other-known-limitations)
- [Additional Information](#additional-information)
  - [Dataset Curators](#dataset-curators)
  - [Licensing Information](#licensing-information)
  - [Citation Information](#citation-information)
  - [Contributions](#contributions)

## Dataset Description

- **Homepage:** [Universal Dependencies](https://universaldependencies.org/)
- **Repository:**
- **Paper:**
- **Leaderboard:**
- **Point of Contact:**

### Dataset Summary

[More Information Needed]

### Supported Tasks and Leaderboards

[More Information Needed]

### Languages

[More Information Needed]

## Dataset Structure

### Data Instances

[More Information Needed]

### Data Fields

[More Information Needed]

### Data Splits

[More Information Needed]

## Dataset Creation

### Curation Rationale

[More Information Needed]

### Source Data

#### Initial Data Collection and Normalization

[More Information Needed]

#### Who are the source language producers?

[More Information Needed]

### Annotations

#### Annotation process

[More Information Needed]

#### Who are the annotators?

[More Information Needed]

### Personal and Sensitive Information

[More Information Needed]

## Considerations for Using the Data

### Social Impact of Dataset

[More Information Needed]

### Discussion of Biases

[More Information Needed]

### Other Known Limitations

[More Information Needed]

## Additional Information

### Dataset Curators

[More Information Needed]

### Licensing Information

[More Information Needed]

### Citation Information

[More Information Needed]
### Contributions

Thanks to [@patrickvonplaten](https://github.com/patrickvonplaten), [@jplu](https://github.com/jplu) for adding this dataset.
